@@ -12,7 +12,12 @@ from .tools.s2_citations import s2_get_citations, s2_get_references
 from .tools.hf_datasets_search import hf_datasets_search
 from .tools.anthology_search import anthology_search
 from .tools.document_qa import document_qa
-from .tools.md_to_pdf import md_to_pdf
+from .tools.latex import (
+    compile_latex_from_file,
+    compile_latex_from_str,
+    get_latex_template,
+    get_latex_templates_list,
+)
 from .tools.web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .tools.visit_webpage import visit_webpage
 from .tools.bitflip import (
@@ -20,6 +25,7 @@ from .tools.bitflip import (
     generate_research_proposal,
     score_research_proposals,
 )
+from .tools.review import review_pdf
 
 
 load_dotenv()
@@ -58,7 +64,10 @@ def run(
     server.add_tool(s2_get_references)
     server.add_tool(hf_datasets_search)
     server.add_tool(anthology_search)
-    server.add_tool(md_to_pdf)
+    server.add_tool(compile_latex_from_file)
+    server.add_tool(compile_latex_from_str)
+    server.add_tool(get_latex_template)
+    server.add_tool(get_latex_templates_list)
     server.add_tool(visit_webpage)
 
     if not disable_web_search_tools:
@@ -76,9 +85,12 @@ def run(
         server.add_tool(generate_research_proposal)
         server.add_tool(score_research_proposals)
         server.add_tool(document_qa)
+        server.add_tool(review_pdf)
 
     if port is None:
-        port = find_free_port()
+        port = int(os.environ.get("PORT", -1))
+        if port == -1:
+            port = find_free_port()
     server.settings.port = port
     server.settings.host = host
     server.run(transport=transport)
