@@ -4,11 +4,16 @@ from .arxiv_download import arxiv_download
 from .hf_datasets_search import hf_datasets_search
 from .s2_citations import s2_get_references, s2_get_citations
 from .document_qa import document_qa
-from .md_to_pdf import md_to_pdf
+from .latex import (
+    compile_latex_from_file,
+    compile_latex_from_str,
+    get_latex_template,
+    get_latex_templates_list,
+)
 from .web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .visit_webpage import visit_webpage
 from .bitflip import extract_bitflip_info, generate_research_proposal, score_research_proposals
-
+from .review import review_pdf
 
 __all__ = [
     "arxiv_search",
@@ -18,7 +23,10 @@ __all__ = [
     "s2_get_citations",
     "hf_datasets_search",
     "document_qa",
-    "md_to_pdf",
+    "compile_latex_from_file",
+    "compile_latex_from_str",
+    "get_latex_template",
+    "get_latex_templates_list",
     "web_search",
     "tavily_web_search",
     "exa_web_search",
@@ -27,4 +35,5 @@ __all__ = [
     "extract_bitflip_info",
     "generate_research_proposal",
     "score_research_proposals",
+    "review_pdf",
 ]
